==> common-web-tools-1.0.3-sources.jar: common/web/tools/webapi/processor/WebApiStatisticsProcessor.java <==
package common.web.tools.webapi.processor;

import com.google.common.base.Strings;
import common.base.tools.statistics.TimeStatisticsTools2;
import common.config.tools.config.ConfigTools3;
import common.web.tools.webapi.annotation.WebApiStatistics;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;

@Aspect
@Service
public class WebApiStatisticsProcessor {
    private static final Logger logger = LoggerFactory.getLogger(WebApiStatisticsProcessor.class);
    private static final String API_STATISTICS_SWITCH_KEY = "api.statistics";

    @Pointcut(value = "@annotation(common.web.tools.webapi.annotation.WebApiStatistics)")
    public void webApiStatisticsCall() {
    }

    @Around(value = "common.web.tools.webapi.processor.WebApiStatisticsProcessor.webApiStatisticsCall()&&@annotation(was)")
    public Object apiInvoke(ProceedingJoinPoint pjp, WebApiStatistics was) throws Throwable {
        String apiName = getApiName(pjp, was);
        boolean isStatistics = getStatisticsSwitch(apiName);

        if (isStatistics) {
            TimeStatisticsTools2.startTimer(apiName);
        }
        Object retVal = pjp.proceed();
        if (isStatistics) {
            TimeStatisticsTools2.stopTimer(apiName);
        }

        return retVal;
    }


    private String getApiName(ProceedingJoinPoint pjp, WebApiStatistics was) {
        String apiName = was.apiName();
        if (Strings.isNullOrEmpty(apiName)) {
            apiName = getApiNameFromRequest(pjp);
        }

        if (!Strings.isNullOrEmpty(apiName)) {
            return apiName.replace("/", "-");
        } else {
            return "";
        }
    }

    private boolean getStatisticsSwitch(String apiName) {
        if (Strings.isNullOrEmpty(apiName)) {
            return false;
        }

        String key = String.format("%s.%s", API_STATISTICS_SWITCH_KEY, apiName);
        return ConfigTools3.getBoolean(key, ConfigTools3.getBoolean(API_STATISTICS_SWITCH_KEY, true));

    }


    private String getApiNameFromRequest(ProceedingJoinPoint pjp) {
        Object[] args = pjp.getArgs();
        if (args.length == 0) {
            return "";
        }

        Object argFirst = args[0];
        if (argFirst instanceof HttpServletRequest) {
            String requestURL = ((HttpServletRequest) argFirst).getRequestURI();
            if (!Strings.isNullOrEmpty(requestURL)) {
                if (requestURL.startsWith("/")) {
                    requestURL = requestURL.substring(1);
                }
                return requestURL.replace("/", "-");
            }
        }

        return "";
    }
}

==> common-web-tools-v3-6.6.7-sources.jar: common/web/tools/webapi/processor/WebApiStatisticsProcessor.java <==
package common.web.tools.webapi.processor;

import com.google.common.base.Strings;
import common.base.tools.statistics.TimeStatisticsTools2;
import common.config.tools.config.ConfigTools3;
import common.web.tools.statistics.scheduler.WebApiStatisticsReportTools;
import common.web.tools.webapi.annotation.WebApiStatistics;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;

@Aspect
@Service
public class WebApiStatisticsProcessor {
    private static final Logger logger = LoggerFactory.getLogger(WebApiStatisticsProcessor.class);
    private static final String API_STATISTICS_SWITCH_KEY = "api.statistics";

    @Pointcut(value = "@annotation(common.web.tools.webapi.annotation.WebApiStatistics)")
    public void webApiStatisticsCall() {
    }

    @Around(value = "common.web.tools.webapi.processor.WebApiStatisticsProcessor.webApiStatisticsCall()&&@annotation(was)")
    public Object apiInvoke(ProceedingJoinPoint pjp, WebApiStatistics was) throws Throwable {
        String apiName = getApiName(pjp, was);
        boolean isStatistics = getStatisticsSwitch(apiName);

        if (isStatistics) {
            TimeStatisticsTools2.startTimer(apiName);
        }
        Object retVal = pjp.proceed();
        if (isStatistics) {
            long time = TimeStatisticsTools2.stopTimer(apiName);
            WebApiStatisticsReportTools.reportSlowRequest(apiName, time);
        }

        return retVal;
    }


    private String getApiName(ProceedingJoinPoint pjp, WebApiStatistics was) {
        String apiName = was.apiName();
        if (Strings.isNullOrEmpty(apiName)) {
            apiName = getApiNameFromRequest(pjp);
        }

        if (!Strings.isNullOrEmpty(apiName)) {
            return apiName.replace("/", "-");
        } else {
            return pjp.toShortString();
        }
    }

    private boolean getStatisticsSwitch(String apiName) {
        if (Strings.isNullOrEmpty(apiName)) {
            return false;
        }

        String key = String.format("%s.%s", API_STATISTICS_SWITCH_KEY, apiName);
        return ConfigTools3.getBoolean(key, ConfigTools3.getBoolean(API_STATISTICS_SWITCH_KEY, true));

    }


    private String getApiNameFromRequest(ProceedingJoinPoint pjp) {
        Object[] args = pjp.getArgs();
        if (args.length == 0) {
            return "";
        }

        Object argFirst = args[0];
        if (argFirst instanceof HttpServletRequest) {
            String requestURL = ((HttpServletRequest) argFirst).getRequestURI();
            if (!Strings.isNullOrEmpty(requestURL)) {
                if (requestURL.startsWith("/")) {
                    requestURL = requestURL.substring(1);
                }
                return requestURL.replace("/", "-");
            }
        }

        return "";
    }
}
